# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.ip_assignment import IPAssignment

class TestIPAssignment(unittest.TestCase):
    """IPAssignment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IPAssignment:
        """Test IPAssignment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IPAssignment`
        """
        model = IPAssignment()
        if include_optional:
            return IPAssignment(
                address = '',
                address_family = 56,
                assigned_to = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                cidr = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                enabled = True,
                gateway = '',
                global_ip = True,
                href = '',
                id = '',
                manageable = True,
                management = True,
                metro = None,
                netmask = '',
                network = '',
                next_hop = '',
                parent_block = equinix.services.metalv1.models.parent_block.ParentBlock(
                    cidr = 56, 
                    href = '', 
                    netmask = '', 
                    network = '', ),
                public = True,
                state = 'pending'
            )
        else:
            return IPAssignment(
                assigned_to = equinix.services.metalv1.models.href.Href(
                    href = '', ),
        )
        """

    def testIPAssignment(self):
        """Test IPAssignment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.metalv1.models.user_limited import UserLimited
from equinix.services.metalv1.models.vrf_metal_gateway import VrfMetalGateway
from typing import Optional, Set
from typing_extensions import Self

class BgpDynamicNeighbor(BaseModel):
    """
    BgpDynamicNeighbor
    """ # noqa: E501
    bgp_neighbor_asn: Optional[Annotated[int, Field(le=4294967295, strict=True, ge=0)]] = Field(default=None, description="The ASN of the dynamic BGP neighbor")
    bgp_neighbor_range: Optional[StrictStr] = Field(default=None, description="Network range of the dynamic BGP neighbor in CIDR format")
    created_at: Optional[datetime] = None
    created_by: Optional[UserLimited] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = Field(default=None, description="The unique identifier for the resource")
    metal_gateway: Optional[VrfMetalGateway] = None
    state: Optional[StrictStr] = None
    tags: Optional[List[StrictStr]] = None
    updated_at: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["bgp_neighbor_asn", "bgp_neighbor_range", "created_at", "created_by", "href", "id", "metal_gateway", "state", "tags", "updated_at"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'deleting', 'pending', 'ready']):
            raise ValueError("must be one of enum values ('active', 'deleting', 'pending', 'ready')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BgpDynamicNeighbor from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "created_at",
            "href",
            "id",
            "state",
            "updated_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['created_by'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metal_gateway
        if self.metal_gateway:
            _dict['metal_gateway'] = self.metal_gateway.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BgpDynamicNeighbor from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bgp_neighbor_asn": obj.get("bgp_neighbor_asn"),
            "bgp_neighbor_range": obj.get("bgp_neighbor_range"),
            "created_at": obj.get("created_at"),
            "created_by": UserLimited.from_dict(obj["created_by"]) if obj.get("created_by") is not None else None,
            "href": obj.get("href"),
            "id": obj.get("id"),
            "metal_gateway": VrfMetalGateway.from_dict(obj["metal_gateway"]) if obj.get("metal_gateway") is not None else None,
            "state": obj.get("state"),
            "tags": obj.get("tags"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EquinixStatus(str, Enum):
    """
    Connection status
    """

    """
    allowed enum values
    """
    REJECTED_ACK = 'REJECTED_ACK'
    REJECTED = 'REJECTED'
    PENDING_DELETE = 'PENDING_DELETE'
    PROVISIONED = 'PROVISIONED'
    BEING_REPROVISIONED = 'BEING_REPROVISIONED'
    BEING_DEPROVISIONED = 'BEING_DEPROVISIONED'
    BEING_PROVISIONED = 'BEING_PROVISIONED'
    CREATED = 'CREATED'
    ERRORED = 'ERRORED'
    PENDING_DEPROVISIONING = 'PENDING_DEPROVISIONING'
    APPROVED = 'APPROVED'
    ORDERING = 'ORDERING'
    PENDING_APPROVAL = 'PENDING_APPROVAL'
    NOT_PROVISIONED = 'NOT_PROVISIONED'
    DEPROVISIONING = 'DEPROVISIONING'
    NOT_DEPROVISIONED = 'NOT_DEPROVISIONED'
    PENDING_AUTO_APPROVAL = 'PENDING_AUTO_APPROVAL'
    PROVISIONING = 'PROVISIONING'
    PENDING_BGP_PEERING = 'PENDING_BGP_PEERING'
    PENDING_PROVIDER_VLAN = 'PENDING_PROVIDER_VLAN'
    DEPROVISIONED = 'DEPROVISIONED'
    DELETED = 'DELETED'
    PENDING_BANDWIDTH_APPROVAL = 'PENDING_BANDWIDTH_APPROVAL'
    AUTO_APPROVAL_FAILED = 'AUTO_APPROVAL_FAILED'
    UPDATE_PENDING = 'UPDATE_PENDING'
    DELETED_API = 'DELETED_API'
    MODIFIED = 'MODIFIED'
    PENDING_PROVIDER_VLAN_ERROR = 'PENDING_PROVIDER_VLAN_ERROR'
    DRAFT = 'DRAFT'
    CANCELLED = 'CANCELLED'
    PENDING_INTERFACE_CONFIGURATION = 'PENDING_INTERFACE_CONFIGURATION'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EquinixStatus from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.get_all_connection_route_filters_response import GetAllConnectionRouteFiltersResponse

class TestGetAllConnectionRouteFiltersResponse(unittest.TestCase):
    """GetAllConnectionRouteFiltersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetAllConnectionRouteFiltersResponse:
        """Test GetAllConnectionRouteFiltersResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetAllConnectionRouteFiltersResponse`
        """
        model = GetAllConnectionRouteFiltersResponse()
        if include_optional:
            return GetAllConnectionRouteFiltersResponse(
                pagination = equinix.services.fabricv4.models.pagination.Pagination(
                    offset = 0, 
                    limit = 0, 
                    total = 0, 
                    next = '', 
                    previous = '', ),
                data = [
                    equinix.services.fabricv4.models.connection_route_filter_data.ConnectionRouteFilterData(
                        href = 'https://api.equinix.com/fabric/v4/connections/81331c52-04c0-4656-a4a7-18c52669348f/routeFilters/695a8471-6595-4ac6-a2f4-b3d96ed3a59d', 
                        type = 'BGP_IPv4_PREFIX_FILTER', 
                        uuid = '695a8471-6595-4ac6-a2f4-b3d96ed3a59d', 
                        attachment_status = 'ATTACHING', 
                        direction = 'INBOUND', )
                    ]
            )
        else:
            return GetAllConnectionRouteFiltersResponse(
        )
        """

    def testGetAllConnectionRouteFiltersResponse(self):
        """Test GetAllConnectionRouteFiltersResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.7.0"

# import apis into sdk package
from equinix.services.metalv1.api.authentication_api import AuthenticationApi
from equinix.services.metalv1.api.bgp_api import BGPApi
from equinix.services.metalv1.api.batches_api import BatchesApi
from equinix.services.metalv1.api.capacity_api import CapacityApi
from equinix.services.metalv1.api.console_log_details_api import ConsoleLogDetailsApi
from equinix.services.metalv1.api.devices_api import DevicesApi
from equinix.services.metalv1.api.emails_api import EmailsApi
from equinix.services.metalv1.api.events_api import EventsApi
from equinix.services.metalv1.api.facilities_api import FacilitiesApi
from equinix.services.metalv1.api.firmware_sets_api import FirmwareSetsApi
from equinix.services.metalv1.api.hardware_reservations_api import HardwareReservationsApi
from equinix.services.metalv1.api.ip_addresses_api import IPAddressesApi
from equinix.services.metalv1.api.incidents_api import IncidentsApi
from equinix.services.metalv1.api.interconnections_api import InterconnectionsApi
from equinix.services.metalv1.api.invitations_api import InvitationsApi
from equinix.services.metalv1.api.invoices_api import InvoicesApi
from equinix.services.metalv1.api.licenses_api import LicensesApi
from equinix.services.metalv1.api.memberships_api import MembershipsApi
from equinix.services.metalv1.api.metal_gateways_api import MetalGatewaysApi
from equinix.services.metalv1.api.metros_api import MetrosApi
from equinix.services.metalv1.api.operating_systems_api import OperatingSystemsApi
from equinix.services.metalv1.api.organizations_api import OrganizationsApi
from equinix.services.metalv1.api.password_reset_tokens_api import PasswordResetTokensApi
from equinix.services.metalv1.api.payment_methods_api import PaymentMethodsApi
from equinix.services.metalv1.api.plans_api import PlansApi
from equinix.services.metalv1.api.ports_api import PortsApi
from equinix.services.metalv1.api.projects_api import ProjectsApi
from equinix.services.metalv1.api.ssh_keys_api import SSHKeysApi
from equinix.services.metalv1.api.self_service_reservations_api import SelfServiceReservationsApi
from equinix.services.metalv1.api.spot_market_api import SpotMarketApi
from equinix.services.metalv1.api.support_request_api import SupportRequestApi
from equinix.services.metalv1.api.transfer_requests_api import TransferRequestsApi
from equinix.services.metalv1.api.two_factor_auth_api import TwoFactorAuthApi
from equinix.services.metalv1.api.usages_api import UsagesApi
from equinix.services.metalv1.api.user_verification_tokens_api import UserVerificationTokensApi
from equinix.services.metalv1.api.userdata_api import UserdataApi
from equinix.services.metalv1.api.users_api import UsersApi
from equinix.services.metalv1.api.vlans_api import VLANsApi
from equinix.services.metalv1.api.vrfs_api import VRFsApi

# import ApiClient
from equinix.services.metalv1.api_response import ApiResponse
from equinix.services.metalv1.api_client import ApiClient
from equinix.services.metalv1.configuration import Configuration
from equinix.services.metalv1.exceptions import OpenApiException
from equinix.services.metalv1.exceptions import ApiTypeError
from equinix.services.metalv1.exceptions import ApiValueError
from equinix.services.metalv1.exceptions import ApiKeyError
from equinix.services.metalv1.exceptions import ApiAttributeError
from equinix.services.metalv1.exceptions import ApiException

# import models into sdk package
from equinix.services.metalv1.models.aws_fabric_provider import AWSFabricProvider
from equinix.services.metalv1.models.activate_hardware_reservation_request import ActivateHardwareReservationRequest
from equinix.services.metalv1.models.address import Address
from equinix.services.metalv1.models.attribute import Attribute
from equinix.services.metalv1.models.attribute_data import AttributeData
from equinix.services.metalv1.models.auth_token import AuthToken
from equinix.services.metalv1.models.auth_token_input import AuthTokenInput
from equinix.services.metalv1.models.auth_token_list import AuthTokenList
from equinix.services.metalv1.models.auth_token_project import AuthTokenProject
from equinix.services.metalv1.models.auth_token_user import AuthTokenUser
from equinix.services.metalv1.models.bgp_session_input import BGPSessionInput
from equinix.services.metalv1.models.batch import Batch
from equinix.services.metalv1.models.batches_list import BatchesList
from equinix.services.metalv1.models.bgp_config import BgpConfig
from equinix.services.metalv1.models.bgp_config_request_input import BgpConfigRequestInput
from equinix.services.metalv1.models.bgp_dynamic_neighbor import BgpDynamicNeighbor
from equinix.services.metalv1.models.bgp_dynamic_neighbor_create_input import BgpDynamicNeighborCreateInput
from equinix.services.metalv1.models.bgp_dynamic_neighbor_list import BgpDynamicNeighborList
from equinix.services.metalv1.models.bgp_neighbor_data import BgpNeighborData
from equinix.services.metalv1.models.bgp_route import BgpRoute
from equinix.services.metalv1.models.bgp_session import BgpSession
from equinix.services.metalv1.models.bgp_session_list import BgpSessionList
from equinix.services.metalv1.models.bgp_session_neighbors import BgpSessionNeighbors
from equinix.services.metalv1.models.bond_port_data import BondPortData
from equinix.services.metalv1.models.capacity_check_per_facility_info import CapacityCheckPerFacilityInfo
from equinix.services.metalv1.models.capacity_check_per_facility_list import CapacityCheckPerFacilityList
from equinix.services.metalv1.models.capacity_check_per_metro_info import CapacityCheckPerMetroInfo
from equinix.services.metalv1.models.capacity_check_per_metro_list import CapacityCheckPerMetroList
from equinix.services.metalv1.models.capacity_input import CapacityInput
from equinix.services.metalv1.models.capacity_level_per_baremetal import CapacityLevelPerBaremetal
from equinix.services.metalv1.models.capacity_list import CapacityList
from equinix.services.metalv1.models.component import Component
from equinix.services.metalv1.models.coordinates import Coordinates
from equinix.services.metalv1.models.create_device_request import CreateDeviceRequest
from equinix.services.metalv1.models.create_email_input import CreateEmailInput
from equinix.services.metalv1.models.create_metal_gateway_request import CreateMetalGatewayRequest
from equinix.services.metalv1.models.create_organization_interconnection_request import CreateOrganizationInterconnectionRequest
from equinix.services.metalv1.models.create_self_service_reservation_request import CreateSelfServiceReservationRequest
from equinix.services.metalv1.models.create_self_service_reservation_request_period import CreateSelfServiceReservationRequestPeriod
from equinix.services.metalv1.models.dedicated_port_create_input import DedicatedPortCreateInput
from equinix.services.metalv1.models.device import Device
from equinix.services.metalv1.models.device_action_input import DeviceActionInput
from equinix.services.metalv1.models.device_actions_inner import DeviceActionsInner
from equinix.services.metalv1.models.device_create_in_facility_input import DeviceCreateInFacilityInput
from equinix.services.metalv1.models.device_create_in_metro_input import DeviceCreateInMetroInput
from equinix.services.metalv1.models.device_create_input import DeviceCreateInput
from equinix.services.metalv1.models.device_created_by import DeviceCreatedBy
from equinix.services.metalv1.models.device_health_rollup import DeviceHealthRollup
from equinix.services.metalv1.models.device_list import DeviceList
from equinix.services.metalv1.models.device_metro import DeviceMetro
from equinix.services.metalv1.models.device_project_lite import DeviceProjectLite
from equinix.services.metalv1.models.device_update_input import DeviceUpdateInput
from equinix.services.metalv1.models.device_usage import DeviceUsage
from equinix.services.metalv1.models.device_usage_list import DeviceUsageList
from equinix.services.metalv1.models.disk import Disk
from equinix.services.metalv1.models.email import Email
from equinix.services.metalv1.models.email_input import EmailInput
from equinix.services.metalv1.models.entitlement import Entitlement
from equinix.services.metalv1.models.error import Error
from equinix.services.metalv1.models.event import Event
from equinix.services.metalv1.models.event_list import EventList
from equinix.services.metalv1.models.fabric_service_token import FabricServiceToken
from equinix.services.metalv1.models.facility import Facility
from equinix.services.metalv1.models.facility_input import FacilityInput
from equinix.services.metalv1.models.facility_input_facility import FacilityInputFacility
from equinix.services.metalv1.models.facility_list import FacilityList
from equinix.services.metalv1.models.filesystem import Filesystem
from equinix.services.metalv1.models.find_ip_address_by_id200_response import FindIPAddressById200Response
from equinix.services.metalv1.models.find_metal_gateway_by_id200_response import FindMetalGatewayById200Response
from equinix.services.metalv1.models.find_traffic_timeframe_parameter import FindTrafficTimeframeParameter
from equinix.services.metalv1.models.firmware_set import FirmwareSet
from equinix.services.metalv1.models.firmware_set_list_response import FirmwareSetListResponse
from equinix.services.metalv1.models.firmware_set_response import FirmwareSetResponse
from equinix.services.metalv1.models.global_bgp_range import GlobalBgpRange
from equinix.services.metalv1.models.global_bgp_range_list import GlobalBgpRangeList
from equinix.services.metalv1.models.hardware_reservation import HardwareReservation
from equinix.services.metalv1.models.hardware_reservation_list import HardwareReservationList
from equinix.services.metalv1.models.href import Href
from equinix.services.metalv1.models.ip_address import IPAddress
from equinix.services.metalv1.models.ip_assignment import IPAssignment
from equinix.services.metalv1.models.ip_assignment_input import IPAssignmentInput
from equinix.services.metalv1.models.ip_assignment_list import IPAssignmentList
from equinix.services.metalv1.models.ip_assignment_metro import IPAssignmentMetro
from equinix.services.metalv1.models.ip_assignment_update_input import IPAssignmentUpdateInput
from equinix.services.metalv1.models.ip_availabilities_list import IPAvailabilitiesList
from equinix.services.metalv1.models.ip_reservation import IPReservation
from equinix.services.metalv1.models.ip_reservation_facility import IPReservationFacility
from equinix.services.metalv1.models.ip_reservation_list import IPReservationList
from equinix.services.metalv1.models.ip_reservation_list_ip_addresses_inner import IPReservationListIpAddressesInner
from equinix.services.metalv1.models.ip_reservation_metro import IPReservationMetro
from equinix.services.metalv1.models.ip_reservation_request_input import IPReservationRequestInput
from equinix.services.metalv1.models.instances_batch_create_input import InstancesBatchCreateInput
from equinix.services.metalv1.models.instances_batch_create_input_batches_inner import InstancesBatchCreateInputBatchesInner
from equinix.services.metalv1.models.interconnection import Interconnection
from equinix.services.metalv1.models.interconnection_fabric_provider import InterconnectionFabricProvider
from equinix.services.metalv1.models.interconnection_list import InterconnectionList
from equinix.services.metalv1.models.interconnection_metro_list import InterconnectionMetroList
from equinix.services.metalv1.models.interconnection_metro_list_metros_inner import InterconnectionMetroListMetrosInner
from equinix.services.metalv1.models.interconnection_metro_list_metros_inner_all_of_providers_inner import InterconnectionMetroListMetrosInnerAllOfProvidersInner
from equinix.services.metalv1.models.interconnection_port import InterconnectionPort
from equinix.services.metalv1.models.interconnection_port_list import InterconnectionPortList
from equinix.services.metalv1.models.interconnection_pricing_list import InterconnectionPricingList
from equinix.services.metalv1.models.interconnection_pricing_list_provider_pricing_inner import InterconnectionPricingListProviderPricingInner
from equinix.services.metalv1.models.interconnection_pricing_list_provider_pricing_inner_tiers_inner import InterconnectionPricingListProviderPricingInnerTiersInner
from equinix.services.metalv1.models.interconnection_update_input import InterconnectionUpdateInput
from equinix.services.metalv1.models.invitation import Invitation
from equinix.services.metalv1.models.invitation_input import InvitationInput
from equinix.services.metalv1.models.invitation_list import InvitationList
from equinix.services.metalv1.models.invoice import Invoice
from equinix.services.metalv1.models.invoice_list import InvoiceList
from equinix.services.metalv1.models.license import License
from equinix.services.metalv1.models.license_create_input import LicenseCreateInput
from equinix.services.metalv1.models.license_list import LicenseList
from equinix.services.metalv1.models.license_update_input import LicenseUpdateInput
from equinix.services.metalv1.models.line_item import LineItem
from equinix.services.metalv1.models.line_item_adjustment import LineItemAdjustment
from equinix.services.metalv1.models.membership import Membership
from equinix.services.metalv1.models.membership_input import MembershipInput
from equinix.services.metalv1.models.membership_list import MembershipList
from equinix.services.metalv1.models.meta import Meta
from equinix.services.metalv1.models.metadata import Metadata
from equinix.services.metalv1.models.metadata_network import MetadataNetwork
from equinix.services.metalv1.models.metadata_network_network import MetadataNetworkNetwork
from equinix.services.metalv1.models.metadata_network_network_bonding import MetadataNetworkNetworkBonding
from equinix.services.metalv1.models.metal_gateway import MetalGateway
from equinix.services.metalv1.models.metal_gateway_create_input import MetalGatewayCreateInput
from equinix.services.metalv1.models.metal_gateway_elastic_ip_create_input import MetalGatewayElasticIpCreateInput
from equinix.services.metalv1.models.metal_gateway_list import MetalGatewayList
from equinix.services.metalv1.models.metal_gateway_list_metal_gateways_inner import MetalGatewayListMetalGatewaysInner
from equinix.services.metalv1.models.metal_gateway_lite import MetalGatewayLite
from equinix.services.metalv1.models.metro import Metro
from equinix.services.metalv1.models.metro_input import MetroInput
from equinix.services.metalv1.models.metro_list import MetroList
from equinix.services.metalv1.models.mount import Mount
from equinix.services.metalv1.models.move_hardware_reservation_request import MoveHardwareReservationRequest
from equinix.services.metalv1.models.new_password import NewPassword
from equinix.services.metalv1.models.operating_system import OperatingSystem
from equinix.services.metalv1.models.operating_system_list import OperatingSystemList
from equinix.services.metalv1.models.organization import Organization
from equinix.services.metalv1.models.organization_input import OrganizationInput
from equinix.services.metalv1.models.organization_list import OrganizationList
from equinix.services.metalv1.models.parent_block import ParentBlock
from equinix.services.metalv1.models.partition import Partition
from equinix.services.metalv1.models.payment_method import PaymentMethod
from equinix.services.metalv1.models.payment_method_billing_address import PaymentMethodBillingAddress
from equinix.services.metalv1.models.payment_method_create_input import PaymentMethodCreateInput
from equinix.services.metalv1.models.payment_method_list import PaymentMethodList
from equinix.services.metalv1.models.payment_method_update_input import PaymentMethodUpdateInput
from equinix.services.metalv1.models.plan import Plan
from equinix.services.metalv1.models.plan_available_in_inner import PlanAvailableInInner
from equinix.services.metalv1.models.plan_available_in_inner_price import PlanAvailableInInnerPrice
from equinix.services.metalv1.models.plan_available_in_metros_inner import PlanAvailableInMetrosInner
from equinix.services.metalv1.models.plan_id_name import PlanIdName
from equinix.services.metalv1.models.plan_list import PlanList
from equinix.services.metalv1.models.plan_specs import PlanSpecs
from equinix.services.metalv1.models.plan_specs_cpus_inner import PlanSpecsCpusInner
from equinix.services.metalv1.models.plan_specs_drives_inner import PlanSpecsDrivesInner
from equinix.services.metalv1.models.plan_specs_features import PlanSpecsFeatures
from equinix.services.metalv1.models.plan_specs_memory import PlanSpecsMemory
from equinix.services.metalv1.models.plan_specs_nics_inner import PlanSpecsNicsInner
from equinix.services.metalv1.models.port import Port
from equinix.services.metalv1.models.port_assign_input import PortAssignInput
from equinix.services.metalv1.models.port_convert_layer3_input import PortConvertLayer3Input
from equinix.services.metalv1.models.port_convert_layer3_input_request_ips_inner import PortConvertLayer3InputRequestIpsInner
from equinix.services.metalv1.models.port_data import PortData
from equinix.services.metalv1.models.port_vlan_assignment import PortVlanAssignment
from equinix.services.metalv1.models.port_vlan_assignment_batch import PortVlanAssignmentBatch
from equinix.services.metalv1.models.port_vlan_assignment_batch_create_input import PortVlanAssignmentBatchCreateInput
from equinix.services.metalv1.models.port_vlan_assignment_batch_create_input_vlan_assignments_inner import PortVlanAssignmentBatchCreateInputVlanAssignmentsInner
from equinix.services.metalv1.models.port_vlan_assignment_batch_list import PortVlanAssignmentBatchList
from equinix.services.metalv1.models.port_vlan_assignment_batch_vlan_assignments_inner import PortVlanAssignmentBatchVlanAssignmentsInner
from equinix.services.metalv1.models.port_vlan_assignment_list import PortVlanAssignmentList
from equinix.services.metalv1.models.project import Project
from equinix.services.metalv1.models.project_create_from_root_input import ProjectCreateFromRootInput
from equinix.services.metalv1.models.project_create_input import ProjectCreateInput
from equinix.services.metalv1.models.project_id_name import ProjectIdName
from equinix.services.metalv1.models.project_list import ProjectList
from equinix.services.metalv1.models.project_update_input import ProjectUpdateInput
from equinix.services.metalv1.models.project_usage import ProjectUsage
from equinix.services.metalv1.models.project_usage_list import ProjectUsageList
from equinix.services.metalv1.models.raid import Raid
from equinix.services.metalv1.models.request_ip_reservation201_response import RequestIPReservation201Response
from equinix.services.metalv1.models.request_ip_reservation_request import RequestIPReservationRequest
from equinix.services.metalv1.models.ssh_key import SSHKey
from equinix.services.metalv1.models.ssh_key_create_input import SSHKeyCreateInput
from equinix.services.metalv1.models.ssh_key_input import SSHKeyInput
from equinix.services.metalv1.models.ssh_key_list import SSHKeyList
from equinix.services.metalv1.models.self_service_reservation_item_request import SelfServiceReservationItemRequest
from equinix.services.metalv1.models.self_service_reservation_item_response import SelfServiceReservationItemResponse
from equinix.services.metalv1.models.self_service_reservation_list import SelfServiceReservationList
from equinix.services.metalv1.models.self_service_reservation_response import SelfServiceReservationResponse
from equinix.services.metalv1.models.server_info import ServerInfo
from equinix.services.metalv1.models.shared_port_vc_vlan_create_input import SharedPortVCVlanCreateInput
from equinix.services.metalv1.models.spot_market_prices_list import SpotMarketPricesList
from equinix.services.metalv1.models.spot_market_prices_per_metro_list import SpotMarketPricesPerMetroList
from equinix.services.metalv1.models.spot_market_prices_per_metro_report import SpotMarketPricesPerMetroReport
from equinix.services.metalv1.models.spot_market_request import SpotMarketRequest
from equinix.services.metalv1.models.spot_market_request_create_input import SpotMarketRequestCreateInput
from equinix.services.metalv1.models.spot_market_request_create_input_instance_parameters import SpotMarketRequestCreateInputInstanceParameters
from equinix.services.metalv1.models.spot_market_request_list import SpotMarketRequestList
from equinix.services.metalv1.models.spot_market_request_metro import SpotMarketRequestMetro
from equinix.services.metalv1.models.spot_prices_datapoints import SpotPricesDatapoints
from equinix.services.metalv1.models.spot_prices_history_report import SpotPricesHistoryReport
from equinix.services.metalv1.models.spot_prices_per_baremetal import SpotPricesPerBaremetal
from equinix.services.metalv1.models.spot_prices_per_facility import SpotPricesPerFacility
from equinix.services.metalv1.models.spot_prices_per_new_facility import SpotPricesPerNewFacility
from equinix.services.metalv1.models.spot_prices_report import SpotPricesReport
from equinix.services.metalv1.models.storage import Storage
from equinix.services.metalv1.models.support_request_input import SupportRequestInput
from equinix.services.metalv1.models.transfer_request import TransferRequest
from equinix.services.metalv1.models.transfer_request_input import TransferRequestInput
from equinix.services.metalv1.models.transfer_request_list import TransferRequestList
from equinix.services.metalv1.models.update_email_input import UpdateEmailInput
from equinix.services.metalv1.models.user import User
from equinix.services.metalv1.models.user_create_input import UserCreateInput
from equinix.services.metalv1.models.user_limited import UserLimited
from equinix.services.metalv1.models.user_list import UserList
from equinix.services.metalv1.models.user_lite import UserLite
from equinix.services.metalv1.models.user_update_input import UserUpdateInput
from equinix.services.metalv1.models.userdata import Userdata
from equinix.services.metalv1.models.verify_email import VerifyEmail
from equinix.services.metalv1.models.virtual_circuit import VirtualCircuit
from equinix.services.metalv1.models.virtual_circuit_create_input import VirtualCircuitCreateInput
from equinix.services.metalv1.models.virtual_circuit_list import VirtualCircuitList
from equinix.services.metalv1.models.virtual_circuit_update_input import VirtualCircuitUpdateInput
from equinix.services.metalv1.models.virtual_network import VirtualNetwork
from equinix.services.metalv1.models.virtual_network_create_input import VirtualNetworkCreateInput
from equinix.services.metalv1.models.virtual_network_list import VirtualNetworkList
from equinix.services.metalv1.models.virtual_network_update_input import VirtualNetworkUpdateInput
from equinix.services.metalv1.models.vlan_csp_connection_create_input import VlanCSPConnectionCreateInput
from equinix.services.metalv1.models.vlan_csp_connection_create_input_fabric_provider import VlanCSPConnectionCreateInputFabricProvider
from equinix.services.metalv1.models.vlan_fabric_vc_create_input import VlanFabricVcCreateInput
from equinix.services.metalv1.models.vlan_virtual_circuit import VlanVirtualCircuit
from equinix.services.metalv1.models.vlan_virtual_circuit_create_input import VlanVirtualCircuitCreateInput
from equinix.services.metalv1.models.vlan_virtual_circuit_update_input import VlanVirtualCircuitUpdateInput
from equinix.services.metalv1.models.vrf import Vrf
from equinix.services.metalv1.models.vrf_bgp_neighbors import VrfBGPNeighbors
from equinix.services.metalv1.models.vrf_bgp_neighbors_list import VrfBGPNeighborsList
from equinix.services.metalv1.models.vrf_create_input import VrfCreateInput
from equinix.services.metalv1.models.vrf_fabric_vc_create_input import VrfFabricVcCreateInput
from equinix.services.metalv1.models.vrf_ip_reservation import VrfIpReservation
from equinix.services.metalv1.models.vrf_ip_reservation_create_input import VrfIpReservationCreateInput
from equinix.services.metalv1.models.vrf_ip_reservation_list import VrfIpReservationList
from equinix.services.metalv1.models.vrf_learned_routes import VrfLearnedRoutes
from equinix.services.metalv1.models.vrf_learned_routes_list import VrfLearnedRoutesList
from equinix.services.metalv1.models.vrf_list import VrfList
from equinix.services.metalv1.models.vrf_metal_gateway import VrfMetalGateway
from equinix.services.metalv1.models.vrf_metal_gateway_create_input import VrfMetalGatewayCreateInput
from equinix.services.metalv1.models.vrf_route import VrfRoute
from equinix.services.metalv1.models.vrf_route_create_input import VrfRouteCreateInput
from equinix.services.metalv1.models.vrf_route_list import VrfRouteList
from equinix.services.metalv1.models.vrf_route_update_input import VrfRouteUpdateInput
from equinix.services.metalv1.models.vrf_update_input import VrfUpdateInput
from equinix.services.metalv1.models.vrf_virtual_circuit import VrfVirtualCircuit
from equinix.services.metalv1.models.vrf_virtual_circuit_create_input import VrfVirtualCircuitCreateInput
from equinix.services.metalv1.models.vrf_virtual_circuit_update_input import VrfVirtualCircuitUpdateInput



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.plan_available_in_inner import PlanAvailableInInner

class TestPlanAvailableInInner(unittest.TestCase):
    """PlanAvailableInInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanAvailableInInner:
        """Test PlanAvailableInInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanAvailableInInner`
        """
        model = PlanAvailableInInner()
        if include_optional:
            return PlanAvailableInInner(
                href = '',
                price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                    hour = 1.23, 
                    href = '', )
            )
        else:
            return PlanAvailableInInner(
        )
        """

    def testPlanAvailableInInner(self):
        """Test PlanAvailableInInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from equinix.services.fabricv4.models.get_route_filter_rules_response import GetRouteFilterRulesResponse
from equinix.services.fabricv4.models.route_filter_rules_base import RouteFilterRulesBase
from equinix.services.fabricv4.models.route_filter_rules_change_data import RouteFilterRulesChangeData
from equinix.services.fabricv4.models.route_filter_rules_change_data_response import RouteFilterRulesChangeDataResponse
from equinix.services.fabricv4.models.route_filter_rules_data import RouteFilterRulesData
from equinix.services.fabricv4.models.route_filter_rules_patch_request_item import RouteFilterRulesPatchRequestItem
from equinix.services.fabricv4.models.route_filter_rules_post_request import RouteFilterRulesPostRequest

from equinix.services.fabricv4.api_client import ApiClient, RequestSerialized
from equinix.services.fabricv4.api_response import ApiResponse
from equinix.services.fabricv4.rest import RESTResponseType


class RouteFilterRulesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_route_filter_rule(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rules_base: RouteFilterRulesBase,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesData:
        """Create Route Filter Rule

        This API provides capability to create a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rules_base: (required)
        :type route_filter_rules_base: RouteFilterRulesBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_route_filter_rule_serialize(
            route_filter_id=route_filter_id,
            route_filter_rules_base=route_filter_rules_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_route_filter_rule_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rules_base: RouteFilterRulesBase,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesData]:
        """Create Route Filter Rule

        This API provides capability to create a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rules_base: (required)
        :type route_filter_rules_base: RouteFilterRulesBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_route_filter_rule_serialize(
            route_filter_id=route_filter_id,
            route_filter_rules_base=route_filter_rules_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_route_filter_rule_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rules_base: RouteFilterRulesBase,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Route Filter Rule

        This API provides capability to create a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rules_base: (required)
        :type route_filter_rules_base: RouteFilterRulesBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_route_filter_rule_serialize(
            route_filter_id=route_filter_id,
            route_filter_rules_base=route_filter_rules_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_route_filter_rule_serialize(
        self,
        route_filter_id,
        route_filter_rules_base,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if route_filter_rules_base is not None:
            _body_params = route_filter_rules_base


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def create_route_filter_rules_in_bulk(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rules_post_request: RouteFilterRulesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetRouteFilterRulesResponse:
        """Bulk Create Route Filter Rules

        This API provides capability to create bulk route filter rules

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rules_post_request: (required)
        :type route_filter_rules_post_request: RouteFilterRulesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_route_filter_rules_in_bulk_serialize(
            route_filter_id=route_filter_id,
            route_filter_rules_post_request=route_filter_rules_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "GetRouteFilterRulesResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_route_filter_rules_in_bulk_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rules_post_request: RouteFilterRulesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetRouteFilterRulesResponse]:
        """Bulk Create Route Filter Rules

        This API provides capability to create bulk route filter rules

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rules_post_request: (required)
        :type route_filter_rules_post_request: RouteFilterRulesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_route_filter_rules_in_bulk_serialize(
            route_filter_id=route_filter_id,
            route_filter_rules_post_request=route_filter_rules_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "GetRouteFilterRulesResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_route_filter_rules_in_bulk_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rules_post_request: RouteFilterRulesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Bulk Create Route Filter Rules

        This API provides capability to create bulk route filter rules

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rules_post_request: (required)
        :type route_filter_rules_post_request: RouteFilterRulesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_route_filter_rules_in_bulk_serialize(
            route_filter_id=route_filter_id,
            route_filter_rules_post_request=route_filter_rules_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "GetRouteFilterRulesResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_route_filter_rules_in_bulk_serialize(
        self,
        route_filter_id,
        route_filter_rules_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if route_filter_rules_post_request is not None:
            _body_params = route_filter_rules_post_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/bulk',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_route_filter_rule_by_uuid(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesData:
        """Delete Route Filter Rule

        This API provides capability to delete a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_route_filter_rule_by_uuid_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesData]:
        """Delete Route Filter Rule

        This API provides capability to delete a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_route_filter_rule_by_uuid_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Route Filter Rule

        This API provides capability to delete a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_route_filter_rule_by_uuid_serialize(
        self,
        route_filter_id,
        route_filter_rule_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        if route_filter_rule_id is not None:
            _path_params['routeFilterRuleId'] = route_filter_rule_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/{routeFilterRuleId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_route_filter_rule_by_uuid(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesData:
        """Get Route Filter Rule By UUID

        This API provides capability to view a Route Filter Rule by UUID

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_route_filter_rule_by_uuid_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesData]:
        """Get Route Filter Rule By UUID

        This API provides capability to view a Route Filter Rule by UUID

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_route_filter_rule_by_uuid_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Route Filter Rule By UUID

        This API provides capability to view a Route Filter Rule by UUID

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_route_filter_rule_by_uuid_serialize(
        self,
        route_filter_id,
        route_filter_rule_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        if route_filter_rule_id is not None:
            _path_params['routeFilterRuleId'] = route_filter_rule_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/{routeFilterRuleId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_route_filter_rule_change_by_uuid(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        change_id: Annotated[StrictStr, Field(description="Route Filter Rule Change UUID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesChangeData:
        """Get Change By ID

        This API provides capability to retrieve a specific Route Filter Rule's Changes

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param change_id: Route Filter Rule Change UUID (required)
        :type change_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_change_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            change_id=change_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RouteFilterRulesChangeData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_route_filter_rule_change_by_uuid_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        change_id: Annotated[StrictStr, Field(description="Route Filter Rule Change UUID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesChangeData]:
        """Get Change By ID

        This API provides capability to retrieve a specific Route Filter Rule's Changes

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param change_id: Route Filter Rule Change UUID (required)
        :type change_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_change_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            change_id=change_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RouteFilterRulesChangeData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_route_filter_rule_change_by_uuid_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        change_id: Annotated[StrictStr, Field(description="Route Filter Rule Change UUID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Change By ID

        This API provides capability to retrieve a specific Route Filter Rule's Changes

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param change_id: Route Filter Rule Change UUID (required)
        :type change_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_change_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            change_id=change_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RouteFilterRulesChangeData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_route_filter_rule_change_by_uuid_serialize(
        self,
        route_filter_id,
        route_filter_rule_id,
        change_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        if route_filter_rule_id is not None:
            _path_params['routeFilterRuleId'] = route_filter_rule_id
        if change_id is not None:
            _path_params['changeId'] = change_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/{routeFilterRuleId}/changes/{changeId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_route_filter_rule_changes(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        offset: Annotated[Optional[StrictInt], Field(description="offset")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="number of records to fetch")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesChangeDataResponse:
        """Get All Changes

        This API provides capability to retrieve all of a Route Filter Rule's Changes

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param offset: offset
        :type offset: int
        :param limit: number of records to fetch
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_changes_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RouteFilterRulesChangeDataResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_route_filter_rule_changes_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        offset: Annotated[Optional[StrictInt], Field(description="offset")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="number of records to fetch")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesChangeDataResponse]:
        """Get All Changes

        This API provides capability to retrieve all of a Route Filter Rule's Changes

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param offset: offset
        :type offset: int
        :param limit: number of records to fetch
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_changes_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RouteFilterRulesChangeDataResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_route_filter_rule_changes_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        offset: Annotated[Optional[StrictInt], Field(description="offset")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="number of records to fetch")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get All Changes

        This API provides capability to retrieve all of a Route Filter Rule's Changes

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param offset: offset
        :type offset: int
        :param limit: number of records to fetch
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rule_changes_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RouteFilterRulesChangeDataResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_route_filter_rule_changes_serialize(
        self,
        route_filter_id,
        route_filter_rule_id,
        offset,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        if route_filter_rule_id is not None:
            _path_params['routeFilterRuleId'] = route_filter_rule_id
        # process the query parameters
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/{routeFilterRuleId}/changes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_route_filter_rules(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        offset: Annotated[Optional[StrictInt], Field(description="offset")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="number of records to fetch")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetRouteFilterRulesResponse:
        """Get Route Filter Rules

        This API provides capability to get all Route Filters Rules for Fabric

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param offset: offset
        :type offset: int
        :param limit: number of records to fetch
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rules_serialize(
            route_filter_id=route_filter_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetRouteFilterRulesResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_route_filter_rules_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        offset: Annotated[Optional[StrictInt], Field(description="offset")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="number of records to fetch")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetRouteFilterRulesResponse]:
        """Get Route Filter Rules

        This API provides capability to get all Route Filters Rules for Fabric

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param offset: offset
        :type offset: int
        :param limit: number of records to fetch
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rules_serialize(
            route_filter_id=route_filter_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetRouteFilterRulesResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_route_filter_rules_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        offset: Annotated[Optional[StrictInt], Field(description="offset")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="number of records to fetch")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Route Filter Rules

        This API provides capability to get all Route Filters Rules for Fabric

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param offset: offset
        :type offset: int
        :param limit: number of records to fetch
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_route_filter_rules_serialize(
            route_filter_id=route_filter_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetRouteFilterRulesResponse",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_route_filter_rules_serialize(
        self,
        route_filter_id,
        offset,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        # process the query parameters
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def patch_route_filter_rule_by_uuid(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        route_filter_rules_patch_request_item: Annotated[List[RouteFilterRulesPatchRequestItem], Field(min_length=1)],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesData:
        """Patch Route Filter Rule

        This API provides capability to partially update a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param route_filter_rules_patch_request_item: (required)
        :type route_filter_rules_patch_request_item: List[RouteFilterRulesPatchRequestItem]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._patch_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            route_filter_rules_patch_request_item=route_filter_rules_patch_request_item,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def patch_route_filter_rule_by_uuid_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        route_filter_rules_patch_request_item: Annotated[List[RouteFilterRulesPatchRequestItem], Field(min_length=1)],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesData]:
        """Patch Route Filter Rule

        This API provides capability to partially update a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param route_filter_rules_patch_request_item: (required)
        :type route_filter_rules_patch_request_item: List[RouteFilterRulesPatchRequestItem]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._patch_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            route_filter_rules_patch_request_item=route_filter_rules_patch_request_item,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def patch_route_filter_rule_by_uuid_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        route_filter_rules_patch_request_item: Annotated[List[RouteFilterRulesPatchRequestItem], Field(min_length=1)],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Patch Route Filter Rule

        This API provides capability to partially update a Route Filter Rule

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param route_filter_rules_patch_request_item: (required)
        :type route_filter_rules_patch_request_item: List[RouteFilterRulesPatchRequestItem]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._patch_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            route_filter_rules_patch_request_item=route_filter_rules_patch_request_item,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _patch_route_filter_rule_by_uuid_serialize(
        self,
        route_filter_id,
        route_filter_rule_id,
        route_filter_rules_patch_request_item,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'RouteFilterRulesPatchRequestItem': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        if route_filter_rule_id is not None:
            _path_params['routeFilterRuleId'] = route_filter_rule_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if route_filter_rules_patch_request_item is not None:
            _body_params = route_filter_rules_patch_request_item


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/{routeFilterRuleId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def replace_route_filter_rule_by_uuid(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        route_filter_rules_base: RouteFilterRulesBase,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RouteFilterRulesData:
        """Replace Route Filter Rule

        This API provides capability to replace a Route Filter Rule completely

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param route_filter_rules_base: (required)
        :type route_filter_rules_base: RouteFilterRulesBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._replace_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            route_filter_rules_base=route_filter_rules_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def replace_route_filter_rule_by_uuid_with_http_info(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        route_filter_rules_base: RouteFilterRulesBase,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RouteFilterRulesData]:
        """Replace Route Filter Rule

        This API provides capability to replace a Route Filter Rule completely

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param route_filter_rules_base: (required)
        :type route_filter_rules_base: RouteFilterRulesBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._replace_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            route_filter_rules_base=route_filter_rules_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def replace_route_filter_rule_by_uuid_without_preload_content(
        self,
        route_filter_id: Annotated[StrictStr, Field(description="Route Filters Id")],
        route_filter_rule_id: Annotated[StrictStr, Field(description="Route  Filter  Rules Id")],
        route_filter_rules_base: RouteFilterRulesBase,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Replace Route Filter Rule

        This API provides capability to replace a Route Filter Rule completely

        :param route_filter_id: Route Filters Id (required)
        :type route_filter_id: str
        :param route_filter_rule_id: Route  Filter  Rules Id (required)
        :type route_filter_rule_id: str
        :param route_filter_rules_base: (required)
        :type route_filter_rules_base: RouteFilterRulesBase
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._replace_route_filter_rule_by_uuid_serialize(
            route_filter_id=route_filter_id,
            route_filter_rule_id=route_filter_rule_id,
            route_filter_rules_base=route_filter_rules_base,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "RouteFilterRulesData",
            '400': "List[Error]",
            '401': "List[Error]",
            '403': "List[Error]",
            '404': "List[Error]",
            '415': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _replace_route_filter_rule_by_uuid_serialize(
        self,
        route_filter_id,
        route_filter_rule_id,
        route_filter_rules_base,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if route_filter_id is not None:
            _path_params['routeFilterId'] = route_filter_id
        if route_filter_rule_id is not None:
            _path_params['routeFilterRuleId'] = route_filter_rule_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if route_filter_rules_base is not None:
            _body_params = route_filter_rules_base


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/fabric/v4/routeFilters/{routeFilterId}/routeFilterRules/{routeFilterRuleId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from equinix.services.metalv1.models.facility import Facility
from equinix.services.metalv1.models.plan import Plan
from equinix.services.metalv1.models.project import Project
from typing import Optional, Set
from typing_extensions import Self

class HardwareReservation(BaseModel):
    """
    HardwareReservation
    """ # noqa: E501
    created_at: Optional[datetime] = None
    custom_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Amount that will be charged for every billing_cycle.")
    device: Optional[Device] = None
    facility: Optional[Facility] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    need_of_service: Optional[StrictBool] = Field(default=None, description="Whether this Device requires assistance from Equinix Metal.")
    plan: Optional[Plan] = None
    project: Optional[Project] = None
    provisionable: Optional[StrictBool] = Field(default=None, description="Whether the reserved server is provisionable or not. Spare devices can't be provisioned unless they are activated first.")
    short_id: Optional[StrictStr] = Field(default=None, description="Short version of the ID.")
    spare: Optional[StrictBool] = Field(default=None, description="Whether the Hardware Reservation is a spare. Spare Hardware Reservations are used when a Hardware Reservations requires service from Equinix Metal")
    switch_uuid: Optional[StrictStr] = Field(default=None, description="Switch short id. This can be used to determine if two devices are connected to the same switch, for example.")
    termination_time: Optional[datetime] = Field(default=None, description="Expiration date for the reservation.")
    __properties: ClassVar[List[str]] = ["created_at", "custom_rate", "device", "facility", "href", "id", "need_of_service", "plan", "project", "provisionable", "short_id", "spare", "switch_uuid", "termination_time"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of HardwareReservation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of device
        if self.device:
            _dict['device'] = self.device.to_dict()
        # override the default output from pydantic by calling `to_dict()` of facility
        if self.facility:
            _dict['facility'] = self.facility.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan
        if self.plan:
            _dict['plan'] = self.plan.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of HardwareReservation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "custom_rate": obj.get("custom_rate"),
            "device": Device.from_dict(obj["device"]) if obj.get("device") is not None else None,
            "facility": Facility.from_dict(obj["facility"]) if obj.get("facility") is not None else None,
            "href": obj.get("href"),
            "id": obj.get("id"),
            "need_of_service": obj.get("need_of_service"),
            "plan": Plan.from_dict(obj["plan"]) if obj.get("plan") is not None else None,
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "provisionable": obj.get("provisionable"),
            "short_id": obj.get("short_id"),
            "spare": obj.get("spare"),
            "switch_uuid": obj.get("switch_uuid"),
            "termination_time": obj.get("termination_time")
        })
        return _obj

from equinix.services.metalv1.models.device import Device
# TODO: Rewrite to not use raise_errors
HardwareReservation.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.invitations_api import InvitationsApi


class TestInvitationsApi(unittest.TestCase):
    """InvitationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InvitationsApi()

    def tearDown(self) -> None:
        pass

    def test_accept_invitation(self) -> None:
        """Test case for accept_invitation

        Accept an invitation
        """
        pass

    def test_decline_invitation(self) -> None:
        """Test case for decline_invitation

        Decline an invitation
        """
        pass

    def test_find_invitation_by_id(self) -> None:
        """Test case for find_invitation_by_id

        View an invitation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.simplified_service_profile import SimplifiedServiceProfile

class TestSimplifiedServiceProfile(unittest.TestCase):
    """SimplifiedServiceProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SimplifiedServiceProfile:
        """Test SimplifiedServiceProfile
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SimplifiedServiceProfile`
        """
        model = SimplifiedServiceProfile()
        if include_optional:
            return SimplifiedServiceProfile(
                href = '',
                type = 'L2_PROFILE',
                name = 'Sample Service Profile',
                uuid = '',
                description = 'offering connectivity to my-network',
                notifications = [
                    equinix.services.fabricv4.models.simplified_notification.SimplifiedNotification(
                        type = 'BANDWIDTH_ALERT', 
                        send_interval = '', 
                        emails = [
                            ''
                            ], 
                        registered_users = [
                            ''
                            ], )
                    ],
                tags = [
                    ''
                    ],
                visibility = 'PRIVATE',
                allowed_emails = [
                    ''
                    ],
                access_point_type_configs = [
                    equinix.services.fabricv4.models.service_profile_access_point_type.ServiceProfileAccessPointType()
                    ],
                custom_fields = [
                    equinix.services.fabricv4.models.custom_field.CustomField(
                        label = 'Account Number', 
                        description = 'Provide a valid account number', 
                        required = True, 
                        data_type = 'STRING', 
                        options = [
                            ''
                            ], 
                        capture_in_email = True, )
                    ],
                marketing_info = equinix.services.fabricv4.models.marketing_info.MarketingInfo(
                    logo = '', 
                    promotion = True, 
                    process_steps = [
                        equinix.services.fabricv4.models.process_step.ProcessStep(
                            title = '', 
                            sub_title = '', 
                            description = '', )
                        ], ),
                ports = [
                    equinix.services.fabricv4.models.service_profile_access_point_colo.ServiceProfileAccessPointCOLO(
                        type = 'XF_PORT', 
                        uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                        location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                            metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                            region = 'AMER, APAC, EMEA', 
                            metro_name = 'Amsterdam', 
                            metro_code = 'AM', 
                            ibx = 'AM1', ), 
                        seller_region = '', 
                        seller_region_description = '', 
                        cross_connect_id = '', )
                    ],
                virtual_devices = [
                    equinix.services.fabricv4.models.service_profile_access_point_vd.ServiceProfileAccessPointVD(
                        type = 'VD', 
                        uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                        location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                            metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                            region = 'AMER, APAC, EMEA', 
                            metro_name = 'Amsterdam', 
                            metro_code = 'AM', 
                            ibx = 'AM1', ), 
                        interface_uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', )
                    ],
                metros = [
                    equinix.services.fabricv4.models.service_metro.ServiceMetro(
                        code = '', 
                        name = '', 
                        vc_bandwidth_max = 56, 
                        ibxs = [
                            ''
                            ], 
                        in_trail = True, 
                        display_name = '', 
                        seller_regions = {
                            'key' : ''
                            }, )
                    ],
                self_profile = True,
                project_id = ''
            )
        else:
            return SimplifiedServiceProfile(
        )
        """

    def testSimplifiedServiceProfile(self):
        """Test SimplifiedServiceProfile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
